summaryrefslogtreecommitdiff
path: root/sd/source/ui/inc/OutlineView.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'sd/source/ui/inc/OutlineView.hxx')
-rwxr-xr-xsd/source/ui/inc/OutlineView.hxx28
1 files changed, 14 insertions, 14 deletions
diff --git a/sd/source/ui/inc/OutlineView.hxx b/sd/source/ui/inc/OutlineView.hxx
index 78481294bf94..e6a4bbb15a98 100755
--- a/sd/source/ui/inc/OutlineView.hxx
+++ b/sd/source/ui/inc/OutlineView.hxx
@@ -121,14 +121,14 @@ public:
DECL_LINK( EndDropHdl, void * );
DECL_LINK( PaintingFirstLineHdl, PaintFirstLineInfo* );
- ULONG GetPaperWidth() const { return 2*21000; } // DIN A4 Breite
+ sal_uLong GetPaperWidth() const { return 2*21000; } // DIN A4 Breite
- BOOL PrepareClose(BOOL bUI = TRUE);
+ sal_Bool PrepareClose(sal_Bool bUI = sal_True);
- virtual BOOL GetAttributes( SfxItemSet& rTargetSet, BOOL bOnlyHardAttr=FALSE ) const;
- virtual BOOL SetAttributes(const SfxItemSet& rSet, BOOL bReplaceAll = FALSE);
+ virtual sal_Bool GetAttributes( SfxItemSet& rTargetSet, sal_Bool bOnlyHardAttr=sal_False ) const;
+ virtual sal_Bool SetAttributes(const SfxItemSet& rSet, sal_Bool bReplaceAll = sal_False);
-// virtual BOOL HasMarkedObjUnused() const;
+// virtual sal_Bool HasMarkedObjUnused() const;
void FillOutliner();
void SetLinks();
void ResetLinks() const;
@@ -141,20 +141,20 @@ public:
const AcceptDropEvent& rEvt,
DropTargetHelper& rTargetHelper,
::sd::Window* pTargetWindow = NULL,
- USHORT nPage = SDRPAGE_NOTFOUND,
- USHORT nLayer = SDRPAGE_NOTFOUND);
+ sal_uInt16 nPage = SDRPAGE_NOTFOUND,
+ sal_uInt16 nLayer = SDRPAGE_NOTFOUND);
virtual sal_Int8 ExecuteDrop (
const ExecuteDropEvent& rEvt,
DropTargetHelper& rTargetHelper,
::sd::Window* pTargetWindow = NULL,
- USHORT nPage = SDRPAGE_NOTFOUND,
- USHORT nLayer = SDRPAGE_NOTFOUND);
+ sal_uInt16 nPage = SDRPAGE_NOTFOUND,
+ sal_uInt16 nLayer = SDRPAGE_NOTFOUND);
// #97766# Re-implement GetScriptType for this view to get correct results
virtual sal_uInt16 GetScriptType() const;
/** After this method has been called with <TRUE/> following changes of
the current page are ignored in that the corresponding text is not
selected.
This is used to supress unwanted side effects between selection and
@@ -171,7 +171,7 @@ public:
/** creates and inserts an empty slide for the given paragraph. */
SdPage* InsertSlideForParagraph( Paragraph* pPara );
- void UpdateParagraph( USHORT nPara );
+ void UpdateParagraph( sal_uInt16 nPara );
protected:
virtual void OnBeginPasteOrDrop( PasteOrDropInfos* pInfos );
@@ -199,10 +199,10 @@ private:
List* mpOldParaOrder;
List* mpSelectedParas;
- USHORT mnPagesToProcess; // fuer die Fortschrittsanzeige
- USHORT mnPagesProcessed;
+ sal_uInt16 mnPagesToProcess; // fuer die Fortschrittsanzeige
+ sal_uInt16 mnPagesProcessed;
- BOOL mbFirstPaint;
+ sal_Bool mbFirstPaint;
SfxProgress* mpProgress;
@@ -141,20 +141,20 @@ public:
// #97766# Re-implement GetScriptType for this view to get correct results
virtual sal_uInt16 GetScriptType() const;
- /** After this method has been called with <TRUE/> following changes of
+ /** After this method has been called with <sal_True/> following changes of
the current page are ignored in that the corresponding text is not
selected.